#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-download
version:              0.2.1.0
visibility:           public
id:                   http-download-0.2.1.0-27EPi4pXBWjDXM7jn73EBt
key:                  http-download-0.2.1.0-27EPi4pXBWjDXM7jn73EBt
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/http-download#readme
synopsis:             Verified downloads with retries
description:
    Higher level HTTP download APIs include verification of content and retries

category:             Development
abi:                  4f86a1a57d3a498a3c4bdd6c2fb80899
exposed:              True
exposed-modules:      Network.HTTP.Download Network.HTTP.Download.Verified
hidden-modules:       Paths_http_download
import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-download-0.2.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-download-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-download-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-download
hs-libraries:         HShttp-download-0.2.1.0-27EPi4pXBWjDXM7jn73EBt
depends:
    base-4.18.2.1 base64-bytestring-1.2.1.0-ClOZjdDh9gTDbeG5SOZFuY
    bytestring-0.11.5.3 conduit-1.3.6.1-2KVA4kOzD7V4xLYumM6ZM8
    conduit-extra-1.3.8-Cyr2Tx2eNo45MPkVGWgN4S
    crypton-1.0.4-A29aWfOF6sn3Zn8WH7qhgd
    crypton-conduit-0.2.3-FSvAtajlOSQ58s2M4YOjvn directory-1.3.8.5
    exceptions-0.10.7 filepath-1.4.300.1
    http-client-0.7.19-8ssF83svLXHI0Lc7hl5yai
    http-conduit-2.3.9.1-9nJOST6EfINDX8XI2pKXEb
    http-types-0.12.4-DSeS6XawuaoHvAFQRL0WJy
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    path-0.9.6-ASbfbOBAqQP4v75YZqojwO
    path-io-1.8.2-6yzhSMk02oKHsUCDpsWZK0
    retry-0.9.3.1-JuLzSG448KlHrl1UpVKmh2
    rio-0.1.24.0-IXPx8WwJk5y4maS0AIPIuU
    rio-prettyprint-0.1.8.0-DvVNkNB3pcHFocKnGhSNaR

haddock-interfaces:
    /usr/share/doc/haskell-http-download/html/http-download.haddock

haddock-html:         /usr/share/doc/haskell-http-download/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

